@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class LogInFile : public QObject
 {
     Q_OBJECT
 public:
-    explicit LogInFile(QObject *parent = Q_NULLPTR);
+    explicit LogInFile(QObject *parent = nullptr);
     ~LogInFile();
 
     QString fileName() const;
