@@ -193,7 +193,6 @@ void ExportMailJob::slotWriteNextArchiveResource()
             QTimer::singleShot(0, this, &ExportMailJob::slotMailsJobTerminated);
         }
     } else {
-        Q_EMIT info(i18n("Resources backup done."));
         QTimer::singleShot(0, this, &ExportMailJob::slotCheckBackupResources);
     }
 }
@@ -204,7 +203,7 @@ void ExportMailJob::backupTransports()
 
     const QString mailtransportsStr(QStringLiteral("mailtransports"));
     const QString maitransportsrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + mailtransportsStr;
-    if (!QFile(maitransportsrc).exists()) {
+    if (!QFileInfo::exists(maitransportsrc)) {
         Q_EMIT info(i18n("Transports backup done."));
     } else {
         KSharedConfigPtr mailtransportsConfig = KSharedConfig::openConfig(mailtransportsStr);
@@ -328,7 +327,7 @@ void ExportMailJob::backupConfig()
 
     const QString folderMailArchiveStr(QStringLiteral("foldermailarchiverc"));
     const QString folderMailArchiverc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + folderMailArchiveStr;
-    if (QFile(folderMailArchiverc).exists()) {
+    if (QFileInfo::exists(folderMailArchiverc)) {
         KSharedConfigPtr archivemailrc = KSharedConfig::openConfig(folderMailArchiveStr);
 
         QTemporaryFile tmp;
@@ -355,7 +354,7 @@ void ExportMailJob::backupConfig()
 
     const QString archiveMailAgentConfigurationStr(QStringLiteral("akonadi_archivemail_agentrc"));
     const QString archiveMailAgentconfigurationrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + archiveMailAgentConfigurationStr;
-    if (QFile(archiveMailAgentconfigurationrc).exists()) {
+    if (QFileInfo::exists(archiveMailAgentconfigurationrc)) {
         KSharedConfigPtr archivemailrc = KSharedConfig::openConfig(archiveMailAgentConfigurationStr);
 
         QTemporaryFile tmp;
@@ -388,7 +387,7 @@ void ExportMailJob::backupConfig()
 
     const QString templatesconfigurationrcStr(QStringLiteral("templatesconfigurationrc"));
     const QString templatesconfigurationrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + templatesconfigurationrcStr;
-    if (QFile(templatesconfigurationrc).exists()) {
+    if (QFileInfo::exists(templatesconfigurationrc)) {
         KSharedConfigPtr templaterc = KSharedConfig::openConfig(templatesconfigurationrcStr);
 
         QTemporaryFile tmp;
@@ -437,13 +436,13 @@ void ExportMailJob::backupConfig()
         }
     }
     const QString adblockFilePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kmail2/adblockrules_local");
-    if (!adblockFilePath.isEmpty()) {
+    if (QFileInfo::exists(adblockFilePath)) {
         backupFile(adblockFilePath, Utils::dataPath() + QLatin1String("kmail2/"), QStringLiteral("adblockrules_local"));
     }
 
     const QString kmailStr(QStringLiteral("kmail2rc"));
     const QString kmail2rc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + kmailStr;
-    if (QFile(kmail2rc).exists()) {
+    if (QFileInfo::exists(kmail2rc)) {
         KSharedConfigPtr kmailrc = KSharedConfig::openConfig(kmail2rc);
 
         QTemporaryFile tmp;
@@ -543,7 +542,7 @@ void ExportMailJob::backupIdentity()
 
     const QString emailidentitiesStr(QStringLiteral("emailidentities"));
     const QString emailidentitiesrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + emailidentitiesStr;
-    if (QFile(emailidentitiesrc).exists()) {
+    if (QFileInfo::exists(emailidentitiesrc)) {
 
         KSharedConfigPtr identity = KSharedConfig::openConfig(emailidentitiesrc);
 
